@@ -1,6 +1,6 @@
 package Koha::Contrib::Sudoc::Loader::Biblios;
 # ABSTRACT: Chargeur de notices biblio
-$Koha::Contrib::Sudoc::Loader::Biblios::VERSION = '2.26';
+$Koha::Contrib::Sudoc::Loader::Biblios::VERSION = '2.27';
 use Moose;
 
 extends 'Koha::Contrib::Sudoc::Loader';
@@ -122,18 +122,14 @@ sub handle_record {
         $self->count_replaced( $self->count_replaced + 1 );
         $self->converter->merge($record, $koha_record);
         $self->converter->clean($record);
-        $self->log->debug(
-            "  Notice après traitement :\n" . $record->as('Text') );
-        $self->log->notice("  * Remplace $biblionumber\n" );
         ModBiblio($record->as('Legacy'), $biblionumber, $framework)
             if $self->doit;
+        $self->converter->biblio_modify($record, $biblionumber, $framework);
     }
     else {
         # Nouvelle notice
         $self->count_added( $self->count_added + 1 );
         $self->converter->clean($record);
-        $self->log->debug(
-            "  Notice après traitement :\n" . $record->as('Text') );
         $framework = $self->converter->framework($record);
         if ( $self->doit ) {
             my $marc = $record->as('Legacy');
@@ -145,11 +141,8 @@ sub handle_record {
                 if @$errors_ref;
             C4::Biblio::_strip_item_fields($marc, $framework);
             ModBiblioMarc($marc, $biblionumber, $framework);
-            $self->log->notice( "  * Ajout $biblionumber $framework\n" );
-        }
-        else {
-            $self->log->notice( "  * Ajout\n" );
         }
+        $self->converter->biblio_add($record, $biblionumber, $framework);
     }
     $self->log->debug("\n");
 }
@@ -168,7 +161,7 @@ Koha::Contrib::Sudoc::Loader::Biblios - Chargeur de notices biblio
 
 =head1 VERSION
 
-version 2.26
+version 2.27
 
 =head1 AUTHOR
 
@@ -176,7 +169,7 @@ Frédéric Demians <f.demians@tamil.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2018 by Fréderic Demians.
+This software is Copyright (c) 2019 by Fréderic Demians.
 
 This is free software, licensed under:
 
